@@ -53,6 +53,7 @@ class AuthConfig:
         else:
                 self.add_json_to_file()
 
+
     def add_json_to_file(self):
         api_access_credentials_object = {"api_key": self.kwargs["api_key"],
                                          "api_auth_token": self.kwargs["api_auth_token"]}
@@ -68,13 +69,14 @@ class AuthConfig:
                                                     api_access_credentials_object})
                     file_reference.seek(0)
                     file_reference.write(json.dumps(api_access_credentials))
-            Py_version_manager.py_print()
+            
             Py_version_manager.py_print("Alias/user_name/Token name successfully added")
         else:
-            Py_version_manager.py_print()
+            
             Py_version_manager.py_print("Invalid credentials given please enter correct Api key and Authorisation")
             return
 
+
     def add_to_config(self):
         file_exist_check_variable = self.check_if_file_exist()
         if file_exist_check_variable == -1:
@@ -92,28 +94,29 @@ class AuthConfig:
             else:
                 self.reserve_keyword_check()
 
-    def delete_from_config(self):
+
+    def delete_from_config(self, x=0):
         file_exist_check_variable = self.check_if_file_exist()
         if file_exist_check_variable == -1 | file_exist_check_variable == 0:
             Py_version_manager.py_print("You need to add your api access credentials using the add functionality ")
-            Py_version_manager.py_print("To know more please write e2e_cli config add -h on your terminal")
+            Py_version_manager.py_print("To know more please write 'e2e_cli alias -h' on your terminal")
 
         elif file_exist_check_variable == 1:
             with open(self.file, 'r+') as file_reference:
                 file_contents_object = json.loads(file_reference.read())
                 delete_output = file_contents_object.pop(self.kwargs["alias"], 'No key found')
-                if delete_output == "No key found":
-                    Py_version_manager.py_print()
+
+                if delete_output == "No key found" and x!=1:
                     Py_version_manager.py_print("No such alias found. Please re-check and enter again")
                 else:
                     file_reference.seek(0)
                     file_reference.write(json.dumps(file_contents_object))
                     file_reference.truncate()
-                    Py_version_manager.py_print()
-                    Py_version_manager.py_print("Alias/name Successfully deteted")
+                    if(x!=1):
+                        Py_version_manager.py_print("Alias/name Successfully deleted")
+
 
     def adding_config_file(self, path):
-        
         # for drag and drop
         if(path[0]=="'" and path[-1]=="'"):
                     path=path.lstrip(path[0])
@@ -129,4 +132,21 @@ class AuthConfig:
             elif platform.system() == "Linux" or platform.system() == "Darwin":    
                 os.system('cp '+ path+ ' '+ self.folder)
 
-            Py_version_manager.py_print("Token file successfuly added")
\ No newline at end of file
+            Py_version_manager.py_print("Token file successfuly added")
+
+
+    def set_default(self):
+        api_access_credentials_object = {"api_key": self.kwargs["api_key"],
+                                         "api_auth_token": self.kwargs["api_auth_token"]}
+        with open(self.file, 'r+') as file_reference:
+                read_string = file_reference.read()
+                if read_string == "":
+                    file_reference.write(json.dumps({"default":
+                                                        api_access_credentials_object}))
+                else:
+                    api_access_credentials = json.loads(read_string)
+                    api_access_credentials.update({"default":
+                                                    api_access_credentials_object})
+                    file_reference.seek(0)
+                    file_reference.truncate(0)                    
+                    file_reference.write(json.dumps(api_access_credentials))
\ No newline at end of file
