@@ -6,24 +6,29 @@ from e2e_cli.core.py_manager import Py_version_manager
 from e2e_cli.core.constants import RESERVES
 
 
-def option_check(alias):
-    if(alias.startswith("@")):
-            return alias.lstrip(alias[0])
-    else:
-          return alias
+# def option_check(alias):
+#     if(alias=="default"):
+#             return get_user_cred(alias)[0]
+#     else:
+#           return alias
 
 
 class AliasServices:
     def __init__(self, alias):
-        self.alias = option_check(alias)
+        self.alias = alias
 
     def get_api_credentials(self):
         file= os.path.expanduser("~") + '/.E2E_CLI/config.json'
         file_reference = open(file, "r")
         config_file_object = json.loads(file_reference.read())
         if self.alias in config_file_object:
-            return {"api_credentials": config_file_object[self.alias],
-                    "message": "Valid alias"}
+            if(self.alias=="default"):
+                default_alias=config_file_object["default"]['api_key']
+                return {"api_credentials": config_file_object[default_alias],
+                        "message": "Valid alias"}
+            else:
+                return {"api_credentials": config_file_object[self.alias],
+                        "message": "Valid alias"}
         else:
             return {"message": "Invalid alias provided"}
 
@@ -36,7 +41,6 @@ def system_file():
 
 def get_user_cred(name, x=0):
     
-    name=option_check(name)
     file= system_file()
 
     # try :
@@ -46,7 +50,12 @@ def get_user_cred(name, x=0):
     # returns JSON object as a dictionary
     data = json.load(f)
 
+    # view list of credentials incase of x==1
     if(name=="all" and x==1):
+                try:
+                    Py_version_manager.py_print("default --> ", data["default"]['api_key'])
+                except:
+                    Py_version_manager.py_print("default --> ", "Not set")
                 return data.keys()
     
     # Closing file
@@ -54,9 +63,12 @@ def get_user_cred(name, x=0):
 
 
     if(name in data):
-        return[ data[name]['api_auth_token'], data[name]['api_key'] ]
+        if(name=="default"):
+            return get_user_cred(data["default"]['api_key'])
+        else:  
+            return[ data[name]['api_auth_token'], data[name]['api_key'] ]
     elif x==2:
         return None
     else:
-        Py_version_manager.py_print("the given alias/credential doesn't exist")
+        Py_version_manager.py_print("Warning : The given alias/credential doesn't exist")
         return None
