@@ -1,5 +1,5 @@
 # constant, reserved keywords
-RESERVES=["alias", "all", "config", "node", "bucket", "lb", "dbaas", "create", "get", "list", "update", "edit", "delete", "file", "doc", "help"]
+RESERVES=["alias", "all", "config", "node", "bucket", "lb", "dbaas", "create", "get", "list", "update", "edit", "delete", "file", "doc", "help", "default"]
 
 #version
 packagke_version="e2e-cli/1.0.0 Python Linux/Mac/Windows"
@@ -9,3 +9,6 @@ packagke_info=" A command line tool developed by E2E Networks Ltd. \r\n Used to
 
 #url for api request
 BASE_URL="https://api.e2enetworks.com/"
+
+
+# for better error handeling, write --action options here for argparser
