@@ -73,15 +73,20 @@ class Checks:
 
     @classmethod
     def manage_exception(self, e):
-                Py_version_manager.py_print("Oops!! An error occurred for more info, type : debug")
-                if(Py_version_manager.py_input("debug/exit ?? ").lower()=="debug"):
-                        Py_version_manager.py_print(e)    
-                        traceback.print_exc()                 
+                    Py_version_manager.py_print(e)    
+                    traceback.print_exc()                 
     
     @classmethod
     def show_json(self, status, e=None):
         if(e!=None):
                 Py_version_manager.py_print("Errors while reading json ",e)
+        Py_version_manager.py_print(json.dumps(status, sort_keys=True, indent=4))
 
-        if(Py_version_manager.py_input("for more info type 'json' ").lower()=="json"):
-                Py_version_manager.py_print(json.dumps(status, sort_keys=True, indent=4))
\ No newline at end of file
+
+    @classmethod
+    def take_input(self, inputs, value):
+        if(value in inputs):
+            # print("gfhg")
+            return inputs.__dict__[value]
+        else:
+            return Py_version_manager.py_input("Please enter "+ value+ " : ")
\ No newline at end of file
