@@ -17,11 +17,11 @@ class Py_version_manager:
                 return input(msg)
     
     @classmethod
-    def py_print(self, *args):
+    def py_print(self, *args, sep=" "):
         # if(int(sys.version[0:1])<3):
         #         print(*args, sep = " ")
         # else:
-                print(*args, sep = " ")
+                print(*args, sep = sep)
                 # return print(args)
 
 
