@@ -6,31 +6,39 @@ from e2e_cli.core.error_logs_service import ErrorLogs
 from e2e_cli.core.py_manager import Py_version_manager
 from e2e_cli.core import help_messages
 
+PARSING_ERROR_MSG=[]
 
 class Main:
     def __init__(self):
         pass
 
     def FormatUsage(self, parser, action):
-        format_string = "e2e_cli" + " alias"+ " " + action + " [-h]" + " {create,delete,list,edit/update} ... "
+        if(action=="alias"):
+            format_string = "e2e_cli" + " alias" + " [-h]" + " {create,delete,list,edit/update} ... "
+        else:
+            format_string = "e2e_cli" + " --alias"+ " " + action + " [-h]" + " {create,delete,list,edit/update} ... "
         parser.usage = format_string
 
     def FormatUsageCommand(self, parser, action, command):
         format_string = "e2e_cli" + " alias=" + "<alias_name>"+ " " + action + " [-h] " + command
         parser.usage = format_string
 
-    def config(self, parser):
-        config_sub_parser = parser.add_subparsers(title="Config Commands", dest="config_commands")
-        config_add_sub_parser = config_sub_parser.add_parser("add", help="To add api key and auth token")
-        config_delete_sub_parser = config_sub_parser.add_parser("delete", help="To delete api key and auth token")
-        config_view_sub_parser = config_sub_parser.add_parser("view", help="To view all alias and credentials")
-        self.FormatUsageCommand(config_add_sub_parser, "config", "add")
-        self.FormatUsageCommand(config_delete_sub_parser, "config", "delete")
-        self.FormatUsageCommand(config_view_sub_parser, "config", "view")
+    def alias(self, parser):
+        alias_sub_parser = parser.add_subparsers(title="Alias Commands", metavar="", dest="alias_commands")
+        alias_add_sub_parser = alias_sub_parser.add_parser("add", help="To add api key and auth token")
+        alias_file_sub_parser = alias_sub_parser.add_parser("add_file", help="To add api key and auth token via file")
+        alias_delete_sub_parser = alias_sub_parser.add_parser("delete", help="To delete api key and auth token")
+        alias_view_sub_parser = alias_sub_parser.add_parser("view", help="To view all alias and credentials")
+        alias_set_default_sub_parser = alias_sub_parser.add_parser("set", help="To set default alias for system")
+        self.FormatUsageCommand(alias_add_sub_parser, "alias", "add")
+        self.FormatUsageCommand(alias_file_sub_parser, "alias", "add_file")
+        self.FormatUsageCommand(alias_delete_sub_parser, "alias", "delete")
+        self.FormatUsageCommand(alias_view_sub_parser, "alias", "view")
+        self.FormatUsageCommand(alias_set_default_sub_parser, "alias", "set")
 
     def node(self, parser):
-        node_sub_parser = parser.add_subparsers(title="node Commands", dest="node_commands")
-        node_action=parser.add_argument('-action', '--action', help="Type of action to be performed your node")
+        node_sub_parser = parser.add_subparsers(title="Node Commands", metavar="", dest="node_commands")
+        node_action=parser.add_argument('--action', help="Type of action to be performed your node")
         node_create_sub_parser = node_sub_parser.add_parser("create", help="To create a new node", formatter_class=help_messages.cli_formatter())
         node_delete_sub_parser = node_sub_parser.add_parser("delete", help="To delete a specific node", formatter_class=help_messages.cli_formatter())
         node_list_sub_parser = node_sub_parser.add_parser("list", help="To get a list of all nodes", formatter_class=help_messages.cli_formatter())
@@ -42,8 +50,8 @@ class Main:
         self.FormatUsageCommand(node_get_sub_parser, "node", "get")
 
     def image(self, parser):
-        image_sub_parser = parser.add_subparsers(title="image Commands", dest="image_commands")
-        image_list=parser.add_argument('-list_by', '--list_by', help="attribute/property by which you want to list images")
+        image_sub_parser = parser.add_subparsers(title="Image Commands", metavar="", dest="image_commands")
+        image_list=parser.add_argument('--list_by', help="attribute/property by which you want to list images")
         image_create_sub_parser = image_sub_parser.add_parser("create", help="To create a new image")
         image_delete_sub_parser = image_sub_parser.add_parser("delete", help="To delete a specific image")
         image_list_sub_parser = image_sub_parser.add_parser("list", help="To get a list of all image")
@@ -55,7 +63,7 @@ class Main:
         self.FormatUsageCommand(image_get_sub_parser, "image", "rename")
 
     def lb(self, parser):
-        node_sub_parser = parser.add_subparsers(title="LB Commands", dest="lb_commands")
+        node_sub_parser = parser.add_subparsers(title="LB Commands", metavar="", dest="lb_commands")
         node_create_sub_parser = node_sub_parser.add_parser("create", help="To create a new node", formatter_class=help_messages.cli_formatter())
         node_delete_sub_parser = node_sub_parser.add_parser("delete", help="To delete a specific node", formatter_class=help_messages.cli_formatter())
         node_list_sub_parser = node_sub_parser.add_parser("list", help="To get a list of all nodes", formatter_class=help_messages.cli_formatter())
@@ -66,8 +74,8 @@ class Main:
         self.FormatUsageCommand(node_edit_sub_parser, "node", "edit")
 
     def bucket(self, parser):
-        bucket_sub_parser = parser.add_subparsers(title="bucket Commands", dest="bucket_commands")
-        bucket_action=parser.add_argument('-action', '--action', help="Type of action to be performed your bucket")
+        bucket_sub_parser = parser.add_subparsers(title="Bucket Commands", metavar="", dest="bucket_commands")
+        bucket_action=parser.add_argument('--action', help="Type of action to be performed your bucket")
         bucket_create_sub_parser = bucket_sub_parser.add_parser("create", help="To create a new bucket")
         bucket_delete_sub_parser = bucket_sub_parser.add_parser("delete", help="To delete a specific bucket")
         bucket_delete_sub_parser = bucket_sub_parser.add_parser("list", help="To get a list of all buckets")
@@ -77,7 +85,7 @@ class Main:
         self.FormatUsageCommand(bucket_delete_sub_parser, "bucket", "list")    
 
     def autoscaling(self, parser):
-        autoscaling_sub_parser = parser.add_subparsers(title="autoscaling Commands", dest="autoscaling_commands")
+        autoscaling_sub_parser = parser.add_subparsers(title="Autoscaling Commands", metavar="", dest="autoscaling_commands")
         autoscaling_create_sub_parser = autoscaling_sub_parser.add_parser("create", help="To create a new bucket")
         autoscaling_delete_sub_parser = autoscaling_sub_parser.add_parser("delete", help="To delete a specific bucket")
         autoscaling_delete_sub_parser = autoscaling_sub_parser.add_parser("list", help="To get a list of all buckets")
@@ -86,7 +94,7 @@ class Main:
         self.FormatUsageCommand(autoscaling_delete_sub_parser, "autoscaling", "list")
 
     def vpc(self, parser):
-        vpc_sub_parser = parser.add_subparsers(title="vpc Commands", dest="vpc_commands")
+        vpc_sub_parser = parser.add_subparsers(title="VPC Commands", metavar="", dest="vpc_commands")
         vpc_create_sub_parser = vpc_sub_parser.add_parser("create", help="To create a new bucket")
         vpc_delete_sub_parser = vpc_sub_parser.add_parser("delete", help="To delete a specific bucket")
         vpc_delete_sub_parser = vpc_sub_parser.add_parser("list", help="To get a list of all buckets")
@@ -95,8 +103,8 @@ class Main:
         self.FormatUsageCommand(vpc_delete_sub_parser, "vpc", "list")
 
     def cdn(self, parser):
-        cdn_sub_parser = parser.add_subparsers(title="cdn Commands", dest="cdn_commands")
-        cdn_action=parser.add_argument('-action', '--action', help="Type of action to be performed your cdn")
+        cdn_sub_parser = parser.add_subparsers(title="CDN Commands", metavar="", dest="cdn_commands")
+        cdn_action=parser.add_argument('--action', help="Type of action to be performed your cdn")
         cdn_create_sub_parser = cdn_sub_parser.add_parser("create", help="To create a new cdn")
         cdn_delete_sub_parser = cdn_sub_parser.add_parser("delete", help="To delete a specific cdn")
         cdn_delete_sub_parser = cdn_sub_parser.add_parser("list", help="To get a list of all cdn")
@@ -106,8 +114,8 @@ class Main:
         self.FormatUsageCommand(cdn_delete_sub_parser, "cdn", "list")
 
     def volumes(self, parser):
-        volumes_sub_parser = parser.add_subparsers(title="volumes Commands", dest="volumes_commands")
-        volumes_action=parser.add_argument('-action', '--action', help="Type of action to be performed your volumes")
+        volumes_sub_parser = parser.add_subparsers(title="Volumes Commands", metavar="", dest="volumes_commands")
+        volumes_action=parser.add_argument('--action', help="Type of action to be performed your volumes")
         volumes_create_sub_parser = volumes_sub_parser.add_parser("create", help="To create a new volumes")
         volumes_delete_sub_parser = volumes_sub_parser.add_parser("delete", help="To delete a specific volumes")
         volumes_delete_sub_parser = volumes_sub_parser.add_parser("list", help="To get a list of all volumes")
@@ -117,8 +125,8 @@ class Main:
         self.FormatUsageCommand(volumes_delete_sub_parser, "volumes", "list")
            
     def dbaas(self, parser):
-        dbaas_sub_parser = parser.add_subparsers(title="DBaaS Commands", dest="dbaas_commands")
-        dbaas_action=parser.add_argument('-action', '--action', help="Type of action to be performed your dbaas")
+        dbaas_sub_parser = parser.add_subparsers(title="DBaaS Commands", metavar="", dest="dbaas_commands")
+        dbaas_action=parser.add_argument('--action', help="Type of action to be performed your dbaas")
         dbaas_create_sub_parser = dbaas_sub_parser.add_parser("create", help="To launch a new dbaas")
         dbaas_delete_sub_parser = dbaas_sub_parser.add_parser("delete", help="To delete a created dbaas")
         dbaas_list_sub_parser = dbaas_sub_parser.add_parser("list", help="To list all of your dbaas")
@@ -128,31 +136,55 @@ class Main:
         self.FormatUsageCommand(dbaas_delete_sub_parser, "dbaas", "delete")
 
 
+class Namespace(argparse._AttributeHolder):
+    """Simple object for storing attributes.
+    copied and over-written/modified here for getting unrecognised commands/inputs
+    """
+
+    def __init__(self, **kwargs):
+        for name in kwargs:
+            setattr(self, name, kwargs[name])
+
+    def __eq__(self, other):
+        if not isinstance(other, Namespace):
+            return NotImplemented
+        return vars(self) == vars(other)
+
+    def __contains__(self, key):
+        return key in self.__dict__
+
+
 class ArgPaser(argparse.ArgumentParser):
 
-    def version_and_pkg_info(self, msg):
-        if("argument -v/--version: expected one argument"==msg):
-            help_messages.e2e_version_info()
-            self.exit()
-
-        if("argument --info: expected one argument"==msg):
-            help_messages.e2e_pakage_info()
-            self.exit()
-
+    # used to collect input values 
+    def inputs_list(self, argv):
+        inputs=Namespace()
+        for element in argv:
+            if "=" in element:
+                    x=element.split("=")
+                    setattr(inputs, x[0], x[1])
+            elif(element.startswith('-')):
+                    setattr(inputs, element.lstrip('-'), True)
+        return inputs        
+        
+    def parse_args(self, args=None, namespace=None):
+        args, argv = self.parse_known_args(args, namespace)
+        if argv:
+            msg = argparse._('unrecognized arguments: %s')
+            self.error(msg % ' '.join(argv))
+        # here args is used for routing to service and inputs as input to service
+        return Namespace(args=args, inputs=self.inputs_list(argv))
 
     def error(self, message):
         args = {'prog': self.prog, 'message': message}
-        self.version_and_pkg_info(args["message"])
-        if("unrecognized arguments: -h" not in args["message"]):
-                        Py_version_manager.py_print( args["message"])
+        if("unrecognized arguments" not in args["message"]):
+                        PARSING_ERROR_MSG.append( args["message"])
 
 
 def commanding(parser):
     sub_parsers = parser.add_subparsers(title="Commands", dest="command")
-    alias_add_parser = sub_parsers.add_parser("add" )
-    alias_add_parser = sub_parsers.add_parser("add_file" )
-    alias_add_parser = sub_parsers.add_parser("view")
-    alias_delete_parser= sub_parsers.add_parser("delete")
+    alias_parser = sub_parsers.add_parser("help", help="To view man doc")
+    alias_parser = sub_parsers.add_parser("alias", help="To add delete tokens" )
     node_parser = sub_parsers.add_parser("node", help="To apply crud operations over Nodes")
     lb_parser = sub_parsers.add_parser("lb", help="To apply operations over Load-Balancer")
     bucket_parser = sub_parsers.add_parser("bucket", help="To create/delete/list buckets of the user")
@@ -163,7 +195,7 @@ def commanding(parser):
     cdn_parser= sub_parsers.add_parser("cdn", help="To create/delete/list cdn for the user")
     volumes_parser= sub_parsers.add_parser("volumes", help="To create/delete/list volume for the user")
     m = Main()
-    # m.config(config_parser)
+    m.alias(alias_parser)
     m.bucket(bucket_parser)
     m.node(node_parser)
     m.dbaas(dbaas_parser)
@@ -174,7 +206,7 @@ def commanding(parser):
     m.cdn(cdn_parser)
     m.volumes(volumes_parser)
 
-    # m.FormatUsage(config_parser, "config")
+    m.FormatUsage(alias_parser, "alias")
     m.FormatUsage(node_parser, "node")
     m.FormatUsage(lb_parser, "lb")
     m.FormatUsage(bucket_parser, "bucket")
@@ -186,15 +218,20 @@ def commanding(parser):
 
 
 def run_main_class():
-    parser = ArgPaser(description="E2E CLI", formatter_class=help_messages.cli_formatter(), add_help=False)
-    parser.add_argument("-v", "--version", default=False)
-    parser.add_argument( "--info", default=False)
-    parser.add_argument("alias", metavar="option", type=str, help="The option to be used or name of your access credentials valid option")
+    parser = ArgPaser(description="E2E CLI", formatter_class=help_messages.cli_formatter())
+
+    #version, info, and alias to be taken first else default
+    parser.add_argument("-v", "--version", action='store_true', help="To view version Info")
+    parser.add_argument( "--info", action='store_true', help="To view package Info")
+    parser.add_argument("--alias", default="default", type=str, help="The name of your access credentials valid option")
+
+    # parsing our commands for routing
     commanding(parser)
 
+    # breakpoint()
     args = parser.parse_args()
     commands_route = CommandsRouting(args)
-    commands_route.route()
+    commands_route.route(PARSING_ERROR_MSG)
    
     
 
