@@ -9,14 +9,12 @@ from e2e_cli.core.helper_service import Checks
 from e2e_cli.core.constants import BASE_URL
 from e2e_cli.node.node_crud.node_listing_service import Nodelisting
 
-
     
 class payload:
-    def __init__(self, alias):
-        self.Option=Py_version_manager.py_input("How would u like to proceed?? For auto input type 'auto' ")
+    def __init__(self, arguments):
 
-        if(self.Option.lower()=="auto"):
-            node_specifications=Nodelisting(alias).node_listing()
+        if('auto' in arguments["inputs"]):
+            node_specifications=Nodelisting(arguments['alias']).node_listing()
             self.image = node_specifications['image']
             self.plan = node_specifications['plan']
             if(node_specifications['location']=='Delhi'):
@@ -24,12 +22,12 @@ class payload:
             else:
                     self.region='mumbai'
         else :
-            self.image = Py_version_manager.py_input("please enter OS you require : ")
-            self.plan = Py_version_manager.py_input("please enter system requirements/plans : ")
-            self.region= Py_version_manager.py_input("please enter region in where server is required : ")
+            self.image = Checks.take_input(arguments["inputs"], "image")
+            self.plan = Checks.take_input(arguments["inputs"], "plan")
+            self.region = Checks.take_input(arguments["inputs"], "region")
                     
-        self.security_group_id = Py_version_manager.py_input("please enter security group id : ")
-        self.name = Py_version_manager.py_input("please enter name of your node : ")
+        self.security_group_id = Checks.take_input(arguments["inputs"], "security_group_id")
+        self.name = Checks.take_input(arguments["inputs"], "name")
         self.ssh_keys = []
 
 
@@ -46,31 +44,32 @@ class NodeCrud:
 
     def create_node(self):
         Py_version_manager.py_print("Creating")
-        my_payload = payload(self.kwargs['alias'])
+        my_payload = payload(self.kwargs)
         API_key = self.API_key
         Auth_Token = self.Auth_Token
         url =  BASE_URL+"myaccount/api/v1/nodes/?apikey=" + API_key+"&location=Delhi"
         req = "POST"
-        if (my_payload.Option=="auto"):
+        if ('auto' in self.kwargs["inputs"]):
                         user_agent='cli_python'
         else:
                 user_agent='cli-e2e'
         my_payload=my_payload.__dict__
-        my_payload.pop('Option')
 
         status = Request(url, Auth_Token, json.dumps(my_payload), req, user_agent).response.json()
-        
-        if Checks.status_result(status,req):
-            try :
-                x = PrettyTable()
-                x.field_names = ["ID", "Name", "Created at", "disk", "Status", "Plan"]
-                x.add_row([status['data']['id'], status['data']['name'],
-                      status['data']['created_at'], status['data']['disk'], status['data']['status'], status['data']['plan']])
-                Py_version_manager.py_print(x)
-            except Exception as e:
-                        Checks.show_json(status, e)
-                        return
+    
+        # if Checks.status_result(status,req):
+        #     try :
+        #         x = PrettyTable()
+        #         x.field_names = ["ID", "Name", "Created at", "disk", "Status", "Plan"]
+        #         x.add_row([status['data']['id'], status['data']['name'],
+        #               status['data']['created_at'], status['data']['disk'], status['data']['status'], status['data']['plan']])
+        #         Py_version_manager.py_print(x)
+        #     except Exception as e:
+        #             Py_version_manager.py_print("Errors : ", e)
 
+        # if('json' in self.kwargs["inputs"]):
+        #     Checks.show_json(status)
+        Checks.status_result(status)
         Checks.show_json(status)
 
 
@@ -78,7 +77,7 @@ class NodeCrud:
         my_payload = {}
         API_key = self.API_key
         Auth_Token = self.Auth_Token
-        node_id = Py_version_manager.py_input("please enter node id : ")
+        node_id = Checks.take_input(self.kwargs["inputs"], "node_id")
         while(not Checks.is_int(node_id)):
               node_id = Py_version_manager.py_input("please enter node id (integer only) ")
         url =  BASE_URL+"myaccount/api/v1/nodes/" + str(node_id) + "/?apikey="+API_key
@@ -91,31 +90,34 @@ class NodeCrud:
                         Py_version_manager.py_print("Node Successfully deleted")
                         Py_version_manager.py_print("use following command -> e2e_cli <alias> node list to check if bucket has been deleted")
             
-            Checks.show_json(status)
-    
+            # if('json' in self.kwargs["inputs"]):
+            #     Checks.show_json(status)
+        Checks.show_json(status)
 
 
     def get_node_by_id(self):
         my_payload = {}
         API_key = self.API_key
         Auth_Token = self.Auth_Token
-        node_id = Py_version_manager.py_input("please enter node id ")
+        node_id = node_id = Checks.take_input(self.kwargs["inputs"], "node_id")
         while(not Checks.is_int(node_id)):
               node_id = Py_version_manager.py_input("please enter node id (integer only) ")
         url =  BASE_URL+"myaccount/api/v1/nodes/" + str(node_id) + "/?apikey="+API_key
         req = "GET"
         status = Request(url, Auth_Token, my_payload, req).response.json()
 
-        if Checks.status_result(status, req):
-            try:
-                x = PrettyTable()
-                x.field_names = ["VM id", "Name", "Created at", "disk", "Plan", "Public IP", "Status"]
-                x.add_row([ status['data']['vm_id'], status['data']['name'], status['data']['created_at'], status['data']['disk'],  status['data']['plan'], status['data']['public_ip_address'], status['data']['status'] ])
-                Py_version_manager.py_print(x)
-            except Exception as e:
-                        Checks.show_json(status, e)
-                        return
+        # if Checks.status_result(status, req):
+        #     try:
+        #         x = PrettyTable()
+        #         x.field_names = ["VM id", "Name", "Created at", "disk", "Plan", "Public IP", "Status"]
+        #         x.add_row([ status['data']['vm_id'], status['data']['name'], status['data']['created_at'], status['data']['disk'],  status['data']['plan'], status['data']['public_ip_address'], status['data']['status'] ])
+        #         Py_version_manager.py_print(x)
+        #     except Exception as e:
+        #                 Py_version_manager.py_print("Errors : ", e)
         
+        # if('json' in self.kwargs["inputs"]):
+        #     Checks.show_json(status)
+        Checks.status_result(status)
         Checks.show_json(status)
 
 
@@ -129,21 +131,24 @@ class NodeCrud:
                        req).response.json()
 
         if parameter == 0:
-            if Checks.status_result(status, req):
-                list=status['data']
-                try:
-                    i = 1
-                    x = PrettyTable()
-                    x.field_names = ["index", "ID", "Name", "Created at", "disk", "Plan", "Status"]
-                    for element in list:
-                        x.add_row([i, element['id'], element['name'],
-                                element['created_at'], element['disk'],  element['plan'],  element['status']])
-                        i = i+1
-                    Py_version_manager.py_print(x)
-                except Exception as e:
-                        Checks.show_json(status, e)
-                        return       
-                Checks.show_json(status)
+            # if Checks.status_result(status, req):
+            #     list=status['data']
+            #     try:
+            #         i = 1
+            #         x = PrettyTable()
+            #         x.field_names = ["index", "ID", "Name", "Plan", "Status"]
+            #         for element in list:
+            #             x.add_row([i, element['id'], element['name'],
+            #                       element['plan'],  element['status']])
+            #             i = i+1
+            #         Py_version_manager.py_print(x)
+            #     except Exception as e:
+            #             Py_version_manager.py_print("Errors : ", e)
+                        
+            #     if('json' in self.kwargs["inputs"]):
+            #         Checks.show_json(status)
+            Checks.status_result(status)
+            Checks.show_json(status)
             
         elif parameter==1:
                     return status['data']
